summaryrefslogtreecommitdiff
path: root/gs/src/gdevdevn.h
diff options
context:
space:
mode:
authorDan Coby <dan.coby@artifex.com>2003-10-07 00:03:12 +0000
committerDan Coby <dan.coby@artifex.com>2003-10-07 00:03:12 +0000
commit76177d394e02a56bf21264d84a0ea67a3d8b8eba (patch)
tree0b42daa02e3c5a6f0648f27b572aab6061d3271f /gs/src/gdevdevn.h
parent2863a92d4f988f6207213373d204255880aa2934 (diff)
downloadghostpdl-76177d394e02a56bf21264d84a0ea67a3d8b8eba.tar.gz
This is part of the fix for 687055. This change splits the DeviceN
parameter handling. The SeparationOrder parameter handling is split into a separate routine. DETAILS: The DeviceN parameter SeparationOrder is used to select which separations are to be included in the output. This parameter is not appropriate for high level devices like pdfwrite. The pdfwrite device does not attempt to separate its output into separations. However the pdfwrite device does use its process color model colors for specifying output colors in some backup cases. If a separation were missing then the it would create an incorrect output color. By splitting out the SeparationOrder parameter we can still use common routines for pdfwrite and other DeviceN output devices. git-svn-id: http://svn.ghostscript.com/ghostscript/trunk@4242 a1074d23-0009-0410-80fe-cf8c14f379e6
Diffstat (limited to 'gs/src/gdevdevn.h')
-rw-r--r--gs/src/gdevdevn.h24
1 files changed, 22 insertions, 2 deletions
diff --git a/gs/src/gdevdevn.h b/gs/src/gdevdevn.h
index 0a4b46423..166cf5d6b 100644
--- a/gs/src/gdevdevn.h
+++ b/gs/src/gdevdevn.h
@@ -94,13 +94,33 @@ typedef gs_devn_params_t gs_devn_params;
extern const fixed_colorant_names_list DeviceCMYKComponents;
/*
* Put the DeviceN related parameters. Note that this routine requires a pointer
* to the DeviceN parametes within the device structure.
*/
int devicen_put_params(gx_device * pdev, gs_devn_params * pparams,
gs_param_list * plist);
/*
+ * Put the DeviceN related parameters. This routine does not handle the
+ * SeparationOrder parameter. Some high level devices do not want the
+ * SeparationOrder parameter to processed. (The use of the SeparationOrder
+ * parameter could result in only some of the separations being present in
+ * the device's output. This is not desired for a device like pdfwrite
+ * which uses the process color model colorants for a backup case to
+ * handle colors. Missing separations would result in missing color values.)
+ *
+ * Note that this routine requires a pointer to the DeviceN parametes within
+ * the device structure.
+ */
+int devicen_put_params_no_sep_order(gx_device * pdev, gs_devn_params * pparams,
+ gs_param_list * plist);
+
+/*
* This routine will check to see if the color component name match those
* of either the process color model colorants or the names on the
* SeparationColorNames list.
@@ -94,13 +94,33 @@ typedef gs_devn_params_t gs_devn_params;
extern const fixed_colorant_names_list DeviceCMYKComponents;
/*
- * Put the DeviceN related parameters. Note that this routine requires a pointer
- * to the DeviceN parametes within the device structure.
+ * Put the DeviceN related parameters.
+ *
+ * Note that this routine requires a pointer to the DeviceN parametes within
+ * the device structure.
+ *
+ * Note: See the devicen_put_params_no_sep_order routine (next) for comments
+ * about the SeparationOrder parameter.
*/
int devicen_put_params(gx_device * pdev, gs_devn_params * pparams,